@@ -5,7 +5,7 @@ use POE qw(Wheel::Run);
 use Storable;
 use vars qw($VERSION);
 
-$VERSION = '1.10';
+$VERSION = '1.12';
 
 my $GOT_KILLFAM;
 
@@ -87,6 +87,10 @@ sub resume_queue {
   $poe_kernel->post( $self->{session_id}, '_spawn_wheel' ) if $pause;
 }
 
+sub paused {
+  return $_[0]->{paused};
+}
+
 sub shutdown {
   my $self = shift;
   $poe_kernel->post( $self->{session_id}, 'shutdown' );
@@ -647,6 +651,10 @@ Pauses processing of the jobs. The current job will finish processing, but any p
 
 Resumes the processing of the pending jobs queue if it has been previously paused.
 
+=item paused
+
+Returns a true value if the job queue is paused or a false value otherwise.
+
 =back
 
 =head1 INPUT EVENTS
